import { __decorate } from "tslib";
import { customElement, observable, volatile } from '@microsoft/fast-element';
import { commonLoginRouteStyles } from '../../styles';
import { logger } from '../../utils';
import { BaseRoute } from '../base';
import { ResetPasswordTemplate as template } from './reset-password.template';
let ResetPassword = class ResetPassword extends BaseRoute {
    constructor() {
        super(...arguments);
        this.hasPasswordExpired = false;
        this.passwordResetToken = '';
    }
    async connectedCallback() {
        super.connectedCallback();
        await this.autofill();
    }
    async enter(phase) {
        this.hasPasswordExpired = !!phase.route.queryParams.expired;
        this.passwordResetToken = phase.route.queryParams.password;
    }
    async onSubmit() {
        await super.onSubmit();
        this.passwordResetToken
            ? await this.onForgotPasswordWorkflow()
            : await this.onChangePasswordWorkflow();
        this.isSubmitting = false;
    }
    async onForgotPasswordWorkflow() {
        logger.debug('forgot password submission');
        const message = this.messageBuilder.createForgotPasswordTokenMessage(this.orgUsername, this.passwordResetToken, this.password2);
        await this.sendMessage(message, 'Password reset success.', () => {
            this.storeCredentials(this.password2);
        });
    }
    async onChangePasswordWorkflow() {
        logger.debug('change password submission');
        const message = this.messageBuilder.createChangePasswordMessage(this.orgUsername, this.password, this.password2);
        await this.sendMessage(message, 'Password change success.', () => {
            this.storeCredentials(this.password2);
        });
    }
    get headingText() {
        return this.hasPasswordExpired ? 'You are required to change your password' : 'Change Password';
    }
};
__decorate([
    observable
], ResetPassword.prototype, "hasPasswordExpired", void 0);
__decorate([
    observable
], ResetPassword.prototype, "passwordResetToken", void 0);
__decorate([
    volatile
], ResetPassword.prototype, "headingText", null);
ResetPassword = __decorate([
    customElement({
        name: 'foundation-login-reset-password',
        template,
        styles: commonLoginRouteStyles,
    })
], ResetPassword);
export { ResetPassword };
